# -*- coding: utf-8 -*-

from .response import SolrResponse
from .mysolr import Solr
from .mysolr import Cursor

__title__ = 'mysolr'
__version__ = '0.7'
__build__ = 0x000070
__author__ = 'Rubén Abad, Miguel Olivares'
